@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw{ Exporter };
 
-our @EXPORT = qw{ process_file };
+our @EXPORT = qw{ process_file };    ## no critic (Modules::ProhibitAutomaticExportation)
 
 our @EXPORT_OK   = qw{ post pre process filter next_line };
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
@@ -23,7 +23,7 @@ Readonly my $FALSE   => 0;
 Readonly my $EMPTY   => q{};
 Readonly my $NL      => "\n";
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our %DEFAULT_PROCESSORS = (
   pre       => \&_pre,
@@ -342,7 +342,7 @@ File::Process - process text files with customer handlers
 
 =head1 SYNOPSIS
 
- use File::Process qw{ process_file };
+ use File::Process;
 
  my ($lines, $info) = process_file($file, process => sub { 
      my ($fh, $lines, $args, $line) = @_;
@@ -378,9 +378,16 @@ text file. The class exports 1 method (C<process_file>) which invokes
 multiple subroutines that you can override or use in conjunction with
 your custom processors.
 
-=head1 METHODS AND SUBROUTINES
+=head1 EXPORTED METHODS
 
-By default, only C<process_file> is exported.
+This module exports 1 method by default (C<process_file>). You can
+export all of the default processor methods using the tag ':all'.
+
+ use File::Process qw{ pre post };
+
+ use File::Process qw{ :all };
+
+=head1 METHODS AND SUBROUTINES
 
 =head2 process_file(file, options)
 
